@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.9 2004/04/21 00:11:34 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.10 2004/04/28 13:52:38 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -579,6 +579,10 @@ static RETSIGTYPE failover_handler(int sig)
 			pids[i] = fork_a_child(unix_fd, inet_fd);
 		}
 
+		close(unix_fd);
+		if (pool_config.inetdomain)
+			close(inet_fd);
+
 		switching = 0;
 
 		if (replication)
