@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.10 2004/03/24 12:27:04 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.14 2004/04/14 00:28:27 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -54,6 +54,10 @@
 /* pid file name */
 #define PID_FILE_NAME "pgpool.pid"
 
+/* strict mode comment in SQL */
+#define STRICT_MODE_STR "/*STRICT*/"
+#define STRICT_MODE(s) (strncasecmp((s), STRICT_MODE_STR, strlen(STRICT_MODE_STR)) == 0)
+
 typedef enum {
     POOL_CONTINUE,
 	POOL_IDLE,
@@ -79,10 +83,19 @@ typedef struct {
     int	max_pool;	/* max # of connection pool per child */
     char *logdir;		/* logging directory */
     char *backend_socket_dir;	/* Unix domain socket directory for the PostgreSQL server */
+	int replication_mode;		/* replication mode */
+	int replication_strict;	/* if non 0, wait for completion of the
+                               query sent to master to avoid deadlock */
+	/*
+	 * if secondary does not respond in this milli seconds, abort this session.
+	 * this is not compatible with replication_strict = 1. 0 means no timeout.
+	 */
+	int replication_timeout;
 
 	/* followings do not exist in the configuration file */
     char	*current_backend_host_name;	/* current backend host name */
     int	current_backend_port;	/* current backend port # */
+	int replication_enabled;		/* replication mode enabled */
 } POOL_CONFIG;
 
 /*
@@ -96,7 +109,10 @@ typedef struct {
 	int po;		/* pending data offset */
 	int bufsz;	/* pending data buffer size */
 	int len;	/* pending data length */
+	char *sbuf;	/* buffer for pool_read_string */
+	int sbufsz;	/* it's size */
 	int isbackend;		/* this connection is for backend if non 0 */
+	int issecondary_backend;		/* this connection is for secondary backend if non 0 */
 } POOL_CONNECTION;
 
 /*
@@ -109,8 +125,18 @@ typedef struct {
     int key;	/* cancel key */
     POOL_CONNECTION	*con;
 	time_t closetime;	/* absolute time in second when the connection closed */
+} POOL_CONNECTION_POOL_SLOT;
+
+#define MAX_CONNECTION_SLOTS 2
+
+typedef struct {
+    int num;	/* number of slots */
+    POOL_CONNECTION_POOL_SLOT	*slots[MAX_CONNECTION_SLOTS];
 } POOL_CONNECTION_POOL;
 
+#define MASTER_CONNECTION(p) ((p)->slots[0])
+#define SECONDARY_CONNECTION(p) ((p)->slots[1])
+
 /*
  * startup packet definitions stolen from PostgreSQL
  */
@@ -151,11 +177,12 @@ extern POOL_CONNECTION_POOL *pool_connection_pool;	/* connection pool */
  */
 extern void pool_error(const char *fmt,...);
 extern void pool_debug(const char *fmt,...);
+extern void pool_log(const char *fmt,...);
 extern int pool_get_config(char *confpath);
 extern void do_child(int unix_fd, int inet_fd);
 extern int pool_init_cp(void);
 extern POOL_STATUS pool_process_query(POOL_CONNECTION *frontend,
-				      POOL_CONNECTION *backend,
+				      POOL_CONNECTION_POOL *backend,
 				      int connection_reuse);
 
 extern POOL_CONNECTION *pool_open(int fd);
@@ -178,14 +205,18 @@ extern POOL_CONNECTION_POOL *pool_get_cp(char *user, char *database);
 extern void pool_discard_cp(char *user, char *database);
 
 extern POOL_STATUS ErrorResponse(POOL_CONNECTION *frontend, 
-								  POOL_CONNECTION *backend);
+								  POOL_CONNECTION_POOL *backend);
 
 void notice_backend_error(void);
 
 void pool_connection_pool_timer(POOL_CONNECTION_POOL *backend);
 RETSIGTYPE pool_backend_timer_handler(int sig);
 
-int connect_inet_domain_socket(POOL_CONNECTION_POOL *p);
-int connect_unix_domain_socket(POOL_CONNECTION_POOL *p);
+int connect_inet_domain_socket(int secondary_backend);
+int connect_unix_domain_socket(int secondary_backend);
+
+int pool_check_fd(POOL_CONNECTION *cp, int notimeout);
+void pool_enable_timeout(void);
+void pool_disable_timeout(void);
 
 #endif /* POOL_H */
