@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_error.c,v 1.3 2004/03/24 00:07:01 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_error.c,v 1.4 2004/03/29 03:42:02 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -53,3 +53,14 @@ void pool_debug(const char *fmt,...)
 	va_end(ap);
 	fprintf(stderr, "\n");
 }
+
+void pool_log(const char *fmt,...)
+{
+	va_list		ap;
+
+	fprintf(stderr, "log: pid %d: ", getpid());
+	va_start(ap, fmt);
+	vfprintf(stderr, fmt, ap);
+	va_end(ap);
+	fprintf(stderr, "\n");
+}
