@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
-* $Header: /home/t-ishii/repository/pgpool/pool_stream.c,v 1.15 2004/04/14 00:28:28 t-ishii Exp $
+* $Header: /home/t-ishii/repository/pgpool/pool_stream.c,v 1.16 2004/04/28 13:52:38 t-ishii Exp $
 *
 * pgpool: a language independent connection pool server for PostgreSQL 
 * written by Tatsuo Ishii
@@ -168,8 +168,10 @@ int pool_read(POOL_CONNECTION *cp, void *buf, int len)
 			}
 			else
 			{
-				/* protocol synchronization may be broken. better to exit this process... */
-				exit(1);
+				/*
+				 * if backend offers authentication method, frontend could close connection
+				 */
+				return -1;
 			}
 		}
 		else if (len > readlen)
